mirror of
https://github.com/ggml-org/whisper.cpp.git
synced 2026-08-05 17:40:51 -05:00
CUDA: fix MMQ stream-k fixup ne1 indices (llama/17089)
This commit is contained in:
committed by
Georgi Gerganov
parent
78ea6c5b67
commit
358f77aca7
@@ -3494,7 +3494,7 @@ static __global__ void mul_mat_q_stream_k_fixup(
|
||||
const int col_diff = col_high - col_low;
|
||||
|
||||
for (int j = threadIdx.y*warp_size + threadIdx.x; j < mmq_x; j += nwarps*warp_size) {
|
||||
ids_dst_shared[j] = ids_dst[col_low + j];
|
||||
ids_dst_shared[j] = ids_dst[col_low + jt*mmq_x + j];
|
||||
}
|
||||
__syncthreads();
|
||||
|
||||
|
||||
Reference in New Issue
Block a user